@@ -94,7 +94,7 @@ void KMouseTool::init_vars()
 
 	// If the ~/.mousetool directory doesn't exist, create it
 //	mSoundFileName = QDir::homeDirPath();
-	mSoundFileName = locate("sound", "mousetool_tap.wav");
+	mSoundFileName = locate("appdata", "sounds/mousetool_tap.wav");
 	mplayer = new KAudioPlayer(mSoundFileName);
 
 
@@ -107,10 +107,13 @@ void KMouseTool::init_vars()
 	// SimpleSoundServer server(Reference("global:Arts_SimpleSoundServer"));
 //	sound_server(Reference("global:Arts_SimpleSoundServer"));
 
+	QDesktopWidget *d = QApplication::desktop();
+	int w = d->width();
+	int h = d->height();
 	MTStroke::setUpperLeft(0,0);
-	MTStroke::setUpperRight(1023,0);
-	MTStroke::setLowerLeft(0,767);
-	MTStroke::setLowerRight(1023,767);
+	MTStroke::setUpperRight(w-1,0);
+	MTStroke::setLowerLeft(0,h-1);
+	MTStroke::setLowerRight(w-1,h-1);
 }
 
 void KMouseTool::resetSettings()
@@ -553,7 +556,7 @@ void KMouseTool::closeSelected()
 	if (newSettings())
 	{
 		int answer = KMessageBox::questionYesNoCancel (this,
-			"<qt>"+i18n("There are unsaved changes in the active module.<br>Do you want to apply the changes before closing the configuration window or discard the changes?"),
+			i18n("There are unsaved changes in the active module.\nDo you want to apply the changes before closing the configuration window or discard the changes?"),
 			i18n("Closing Configuration Window"),
 			KStdGuiItem::apply(), KStdGuiItem::discard(), "AutomaticSave");
 		if (answer == KMessageBox::Yes)
@@ -572,7 +575,7 @@ void KMouseTool::quitSelected()
 	if (newSettings())
 	{
 		int answer = KMessageBox::questionYesNoCancel (this,
-			"<qt>"+i18n("There are unsaved changes in the active module.<br>Do you want to apply the changes before quitting KMousetool or discard the changes?"),
+			i18n("There are unsaved changes in the active module.\nDo you want to apply the changes before quitting KMousetool or discard the changes?"),
 			i18n("Quitting KMousetool"),
 			KStdGuiItem::apply(), KStdGuiItem::discard(), "AutomaticSave");
 		if (answer == KMessageBox::Yes)
