@@ -287,7 +287,7 @@ int PhraseBook::save (QWidget *parent, const QString &title, KURL &url, bool phr
       }
       else if (url.fileName (false).right (11).contains (".phrasebook", false) == 0) {
          int filetype = KMessageBox::questionYesNoCancel (0,QString("<qt>%1</qt>").arg(i18n("Your chosen filename <i>%1</i> has a different extension than <i>.phrasebook</i>. "
-                                                           "Do you wish to add <i>.phrasebook</i> to the filename?").arg(url.filename())),i18n("File Extension"));
+                                                           "Do you wish to add <i>.phrasebook</i> to the filename?").arg(url.filename())),i18n("File Extension"),i18n("Add"),i18n("Do Not Add"));
          if (filetype == KMessageBox::Cancel) {
             return 0;
          }
