@@ -27,6 +27,7 @@
 #include <qpopupmenu.h>
 #include <qvaluestack.h>
 #include <qptrstack.h>
+#include <qwhatsthis.h>
 
 // include files for KDE
 #include <kpopupmenu.h>
@@ -212,7 +213,7 @@ void InitialPhraseBookWidget::createBook () {
       else {
          if (((QCheckListItem*)item)->isOn()) {
             PhraseBook localBook;
-            localBook.open(item->text(PhraseBookPrivate::filename));
+            localBook.open(KURL( item->text(PhraseBookPrivate::filename )));
             book += localBook;
          }
          
@@ -226,7 +227,7 @@ void InitialPhraseBookWidget::createBook () {
 
    QString bookLocation = KApplication::kApplication()->dirs()->saveLocation ("appdata", "/");
    if (!bookLocation.isNull() && !bookLocation.isEmpty()) {
-      book.save (bookLocation + "standard.phrasebook");
+      book.save (KURL( bookLocation + "standard.phrasebook" ));
    }
 }
 
@@ -238,6 +239,7 @@ ButtonBoxWidget::ButtonBoxWidget (QWidget *parent, const char *name)
 
    keyButton = new KKeyButton (keyButtonPlace, "key");
    keyButtonPlaceLayout->addWidget (keyButton, 1,1);
+   QWhatsThis::add (keyButton, i18n("By clicking on this button you can select the keyboard shortcut associated with the selected phrase."));
 
    group = new QButtonGroup (phrasebox);
    group->hide();
@@ -265,11 +267,11 @@ PhraseBookDialog::PhraseBookDialog ()
    QString standardBook = KApplication::kApplication()->dirs()->findResource("appdata", "standard.phrasebook");
    if (!standardBook.isNull() && !standardBook.isEmpty()) {
       PhraseBook book;
-      book.open(standardBook);
+      book.open(KURL( standardBook ));
       treeView->clear();
       treeView->addBook(0, 0, &book);
       treeView->setCurrentItem(treeView->firstChild());
-      currentChanged(treeView->currentItem());
+      selectionChanged();
       phrasebookChanged = false;
    }
    // i18n("Edit Phrase Book")
@@ -300,7 +302,8 @@ void PhraseBookDialog::initGUI () {
    treeView->setRootIsDecorated (true);
    treeView->setAllColumnsShowFocus (true);
    treeView->setSelectionMode (QListView::Extended); 
-   connect (treeView, SIGNAL(currentChanged(QListViewItem *)), this, SLOT(currentChanged(QListViewItem *)));
+   QWhatsThis::add (treeView, i18n("This list contains the current phrase book in a tree structure. You can select and modify individual phrases and sub phrase books"));
+   connect (treeView, SIGNAL(selectionChanged()), this, SLOT(selectionChanged()));
    connect (treeView, SIGNAL(contextMenuRequested (QListViewItem *, const QPoint &, int)), this, SLOT(contextMenuRequested (QListViewItem *, const QPoint &, int)));
    connect (treeView, SIGNAL(dropped (QDropEvent *, QListViewItem *, QListViewItem *)), this, SLOT(slotDropped (QDropEvent *, QListViewItem *, QListViewItem *)));
    connect (treeView, SIGNAL(moved (QListViewItem *, QListViewItem *, QListViewItem *)), this, SLOT(slotMoved (QListViewItem *, QListViewItem *, QListViewItem *)));
@@ -314,7 +317,7 @@ void PhraseBookDialog::initGUI () {
    mainLayout->addWidget (buttonBox);
 
    treeView->setFocus();
-   currentChanged(0);
+   selectionChanged();
 }
 
 void PhraseBookDialog::initActions() {
@@ -407,7 +410,7 @@ StandardBookList PhraseBookDialog::standardPhraseBooks() {
    QStringList::iterator it;
    for (it = bookPaths.begin(); it != bookPaths.end(); ++it) {
       PhraseBook pbook;
-      if (pbook.open (*it)) {
+      if (pbook.open (KURL( *it ))) {
          StandardBook book;
          book.name = (*pbook.begin()).getPhrase().getPhrase();
          
@@ -466,9 +469,24 @@ void PhraseBookDialog::initStandardPhraseBooks () {
    }
 }
 
-void PhraseBookDialog::currentChanged (QListViewItem *item) {
+PhraseTreeItem *selectedItem (QListView *treeView) {
+   PhraseTreeItem *currentItem = (PhraseTreeItem *)treeView->currentItem();
+   if ((currentItem == 0) || (!currentItem->isSelected()))
+      return 0;
+
+   QListViewItemIterator it(treeView);
+   while (it.current()) {
+      QListViewItem *item = it.current();
+      if (item->isSelected() && (item != currentItem))
+         return 0;
+      ++it;
+   }
+   return currentItem;
+}
+
+void PhraseBookDialog::selectionChanged () {
    bool modified = phrasebookChanged;
-   PhraseTreeItem *currentItem = (PhraseTreeItem *)item;
+   PhraseTreeItem *currentItem = selectedItem (treeView);
    if (currentItem == 0) {
       buttonBox->textLabel->setText (i18n("Text of the &phrase:"));
       buttonBox->textLabel->setEnabled(false);
@@ -476,7 +494,7 @@ void PhraseBookDialog::currentChanged (QListViewItem *item) {
       buttonBox->lineEdit->setText("");
       buttonBox->lineEdit->setEnabled(false);
       buttonBox->shortcutLabel->setEnabled(false);
-      buttonBox->keyButton->setShortcut("");
+      buttonBox->keyButton->setShortcut("", false);
       buttonBox->keyButton->setEnabled(false);
       buttonBox->noKey->setChecked (false);
       buttonBox->noKey->setEnabled (false);
@@ -491,7 +509,7 @@ void PhraseBookDialog::currentChanged (QListViewItem *item) {
       buttonBox->lineEdit->setEnabled(true);
       buttonBox->shortcutLabel->setEnabled(true);
       QString shortcut = currentItem->text(1);
-      buttonBox->keyButton->setShortcut(currentItem->cut());
+      buttonBox->keyButton->setShortcut(currentItem->cut(), false);
       if (shortcut.isEmpty() || shortcut.isNull()) {
          buttonBox->noKey->setChecked (true);
          buttonBox->customKey->setChecked (false);
@@ -511,7 +529,7 @@ void PhraseBookDialog::currentChanged (QListViewItem *item) {
       buttonBox->lineEdit->setText(currentItem->text(0));
       buttonBox->lineEdit->setEnabled(true);
       buttonBox->shortcutLabel->setEnabled(false);
-      buttonBox->keyButton->setShortcut("");
+      buttonBox->keyButton->setShortcut("", false);
       buttonBox->keyButton->setEnabled(false);
       buttonBox->noKey->setChecked (false);
       buttonBox->noKey->setEnabled (false);
@@ -524,7 +542,7 @@ void PhraseBookDialog::currentChanged (QListViewItem *item) {
 bool PhraseBookDialog::queryClose() {
    if (phrasebookChanged) {
       int answer = KMessageBox::questionYesNoCancel (this,
-          i18n("There are unsaved changes.<br>Do you want to apply the changes before closing the \"phrase book\" window or discard the changes?"),
+              i18n("<qt>There are unsaved changes.<br>Do you want to apply the changes before closing the \"phrase book\" window or discard the changes?</qt>"),
           i18n("Closing \"Phrase Book\" Window"),
           KStdGuiItem::apply(), KStdGuiItem::discard(), "AutomaticSave");
       if (answer == KMessageBox::Yes) {
@@ -537,8 +555,8 @@ bool PhraseBookDialog::queryClose() {
 }
 
 void PhraseBookDialog::slotTextChanged (const QString &s) {
-   PhraseTreeItem *currentItem = (PhraseTreeItem *)treeView->currentItem();
-   if (currentItem != 0 && currentItem->isSelected())
+   PhraseTreeItem *currentItem = selectedItem (treeView);
+   if (currentItem != 0)
       currentItem->setText(0, s);
    phrasebookChanged = true;
 }
@@ -547,10 +565,10 @@ void PhraseBookDialog::slotNoKey() {
    buttonBox->noKey->setChecked (true);
    buttonBox->customKey->setChecked (false);
    
-   PhraseTreeItem *currentItem = (PhraseTreeItem *)treeView->currentItem();
-   if (currentItem != 0 && currentItem->isSelected()) {
+   PhraseTreeItem *currentItem = selectedItem (treeView);
+   if (currentItem != 0) {
       currentItem->setCut (KShortcut(QString::null));
-      buttonBox->keyButton->setShortcut(currentItem->cut());
+      buttonBox->keyButton->setShortcut(currentItem->cut(), false);
    }
    phrasebookChanged = true;
 }
@@ -585,7 +603,7 @@ void PhraseBookDialog::setShortcut( const KShortcut& cut ) {
       }
    }
 
-   PhraseTreeItem *currentItem = (PhraseTreeItem *)treeView->currentItem();
+   PhraseTreeItem *currentItem = selectedItem (treeView);
    // If key isn't already in use,
    if (!treeView->isKeyPresent (cut, currentItem, true)) {
       // Set new key code
@@ -593,14 +611,16 @@ void PhraseBookDialog::setShortcut( const KShortcut& cut ) {
       // Update display
       buttonBox->noKey->setChecked (false);
       buttonBox->customKey->setChecked (true);
-      buttonBox->keyButton->setShortcut(currentItem->cut());
+      buttonBox->keyButton->setShortcut(currentItem->cut(), false);
    }
 }
 
 QListViewItem *PhraseBookDialog::addBook (QListViewItem *parent, QListViewItem *after, PhraseBook *book) {
    QListViewItem *newItem = treeView->addBook(parent, after, book);
    if (newItem != 0) {
+      treeView->clearSelection();
       treeView->ensureItemVisible(newItem);
+      treeView->setCurrentItem (newItem);
       treeView->setSelected (newItem, true);
       phrasebookChanged = true;
    }
@@ -635,6 +655,7 @@ void PhraseBookDialog::contextMenuRequested(QListViewItem *, const QPoint &pos,
 void PhraseBookDialog::slotRemove () {
    if (treeView->hasSelectedItems() != 0)
       treeView->deleteSelectedItems();
+   selectionChanged();
    phrasebookChanged = true;
 }
 
@@ -671,7 +692,7 @@ void PhraseBookDialog::slotMoved (QListViewItem *item, QListViewItem *, QListVie
 
 void PhraseBookDialog::slotAddPhrasebook () {
    PhraseBook book;
-   Phrase phrase(i18n("(New phrase book)"), "");
+   Phrase phrase(i18n("(New Phrase Book)"), "");
    book += PhraseBookEntry(phrase, 0, false);
 
    QListViewItem *item = addBook (treeView->currentItem(), &book);
@@ -682,7 +703,7 @@ void PhraseBookDialog::slotAddPhrasebook () {
 
 void PhraseBookDialog::slotAddPhrase () {
    PhraseBook book;
-   Phrase phrase(i18n("(New phrase)"), "");
+   Phrase phrase(i18n("(New Phrase)"), "");
    book += PhraseBookEntry(phrase, 0, true);
 
    addBook (treeView->currentItem(), &book);
