@@ -34,7 +34,10 @@
 #include <dcopclient.h>
 #include <knotifyclient.h>
 #include <krun.h>
+#include <kaboutdata.h>
 
+// KTTS includes.
+#include "notify.h"
 #include "kttsd.h"
 
 /**
@@ -96,8 +99,23 @@ bool KTTSD::initializeTalkerMgr()
 
         m_talkerMgr = new TalkerMgr(this, "kttsdtalkermgr");
         int load = m_talkerMgr->loadPlugIns(m_speechData->config);
-        if(load < 0)
+        // If no Talkers configured, try to autoconfigure one, first in the user's
+        // desktop language, but if that fails, fallback to English.
+        if (load < 0)
         {
+            QString languageCode = KGlobal::locale()->language();
+            if (m_talkerMgr->autoconfigureTalker(languageCode, m_speechData->config))
+                load = m_talkerMgr->loadPlugIns(m_speechData->config);
+            else
+            {
+                if (m_talkerMgr->autoconfigureTalker("en", m_speechData->config))
+                    load = m_talkerMgr->loadPlugIns(m_speechData->config);
+            }
+        }
+        if (load < 0)
+        {
+            // TODO: Would really like to eliminate ALL GUI stuff from kttsd.  Find
+            // a better way to do this.
             delete m_speaker;
             m_speaker = 0;
             delete m_talkerMgr;
@@ -105,19 +123,19 @@ bool KTTSD::initializeTalkerMgr()
             delete m_speechData;
             m_speechData = 0;
             kdDebug() << "KTTSD::initializeTalkerMgr: no Talkers have been configured." << endl;
-           // Ask if user would like to run configuration dialog, but don't bug user unnecessarily.
+            // Ask if user would like to run configuration dialog, but don't bug user unnecessarily.
             QString dontAskConfigureKTTS = "DontAskConfigureKTTS";
             KMessageBox::ButtonCode msgResult;
             if (KMessageBox::shouldBeShownYesNo(dontAskConfigureKTTS, msgResult))
             {
                 if (KMessageBox::questionYesNo(
                     0,
-                i18n("KTTS has not yet been configured.  At least one Talker must be configured.  "
+                    i18n("KTTS has not yet been configured.  At least one Talker must be configured.  "
                         "Would you like to configure it now?"),
-                i18n("KTTS Not Configured"),
-		KStdGuiItem::yes(),
-		KStdGuiItem::no(),
-                dontAskConfigureKTTS) == KMessageBox::Yes) msgResult = KMessageBox::Yes;
+                    i18n("KTTS Not Configured"),
+                    i18n("Configure"),
+                    i18n("Do Not Configure"),
+                    dontAskConfigureKTTS) == KMessageBox::Yes) msgResult = KMessageBox::Yes;
             }
             if (msgResult == KMessageBox::Yes) showDialog();
             return false;
@@ -183,6 +201,11 @@ KTTSD::~KTTSD(){
 */
 bool KTTSD::supportsMarkup(const QString& talker /*=NULL*/, const uint markupType /*=0*/) const
 {
+    if (markupType == KSpeech::mtHtml)
+    {
+        if (!m_speechData) return false;
+        return m_speechData->supportsHTML;
+    }
     if (markupType != KSpeech::mtSsml) return false;
     if (!m_talkerMgr) return false;
     return m_talkerMgr->supportsMarkup(fixNullString(talker), markupType);
@@ -308,6 +331,41 @@ uint KTTSD::setText(const QString &text, const QString &talker /*=NULL*/)
     return jobNum;
 }
 
+/**
+* Say a plain text job.  This is a convenience method that
+* combines @ref setText and @ref startText into a single call.
+* @param text           The message to be spoken.
+* @param talker         Code for the talker to do the speaking.  Example "en".
+*                       If NULL, defaults to the user's default plugin.
+*                       If no plugin has been configured for the specified Talker code,
+*                       defaults to the closest matching talker.
+* @return               Job number.
+*
+* Plain text is parsed into individual sentences using the current sentence delimiter.
+* Call @ref setSentenceDelimiter to change the sentence delimiter prior to
+* calling setText.
+* Call @ref getTextCount to retrieve the sentence count after calling setText.
+*
+* The text may contain speech mark language, such as Sable, JSML, or SSML,
+* provided that the speech plugin/engine support it.  In this case,
+* sentence parsing follows the semantics of the markup language.
+*
+* The job is marked speakable.
+* If there are other speakable jobs preceeding this one in the queue,
+* those jobs continue speaking and when finished, this job will begin speaking.
+* If there are no other speakable jobs preceeding this one, it begins speaking.
+*
+* @see getTextCount
+*
+* @since KDE 3.5
+*/
+uint KTTSD::sayText(const QString &text, const QString &talker)
+{
+    uint jobNum = setText(text, talker);
+    if (jobNum) startText(jobNum);
+    return jobNum;
+}
+
 /**
 * Adds another part to a text job.  Does not start speaking the text.
 * (thread safe)
@@ -546,7 +604,25 @@ void KTTSD::startText(const uint jobNum /*=0*/)
 {
     kdDebug() << "KTTSD::startText: Running" << endl;
     if (!m_speaker) return;
-    m_speaker->startText(applyDefaultJobNum(jobNum));
+    // Determine if we are starting speech.
+    bool startingSpeech = !isSpeakingText();
+    uint jNum = applyDefaultJobNum(jobNum);
+    m_speaker->startText(jNum);
+    // If this has started speech output, determine whether to autostart KTTSMgr.
+    if (startingSpeech)
+    {
+        if (m_speechData->autoStartManager)
+        {
+            // Do not start KTTSMgr unless at least 5 sentences are queued.
+            if (getTextCount(jNum) > 4)
+            {
+                QString cmd = "kttsmgr --systray";
+                if (m_speechData->autoExitManager) cmd.append(" --autoexit");
+                // Notice this fails if KTTSMgr is already running, which is what we want.
+                KRun::runCommand(cmd);
+            }
+        }
+    }
 }
 
 /**
@@ -597,7 +673,11 @@ void KTTSD::pauseText(const uint jobNum /*=0*/)
 *
 * The job is marked speakable.
 *
-* If the job was not paused, it is the same as calling @ref startText.
+* If the job is currently speaking, or is waiting to be spoken (speakable 
+* state), the resumeText() call is ignored.
+*
+* If the job is currently queued, or is finished, it is the same as calling
+* @ref startText .
 *
 * If there are speaking jobs preceeding this one in the queue, those jobs continue speaking and,
 * when finished this job will begin speaking where it left off.
@@ -764,6 +844,11 @@ void KTTSD::reinit()
     ready();
 }
 
+/**
+* Return KTTSD daemon version number.
+*/
+QString KTTSD::version() { return kapp->aboutData()->version(); }
+
 /*
 * Checks if KTTSD is ready to speak and at least one talker is configured.
 * If not, user is prompted to display the configuration dialog.
@@ -792,21 +877,114 @@ void KTTSD::configCommitted() {
 * default_presentation contains these ORed events: None=0, Sound=1, Messagebox=2, Logfile=4, Stderr=8,
 * PassivePopup=16, Execute=32, Taskbar=64
 */
-void KTTSD::notificationSignal( const QString&, const QString&,
-    const QString &text, const QString&, const QString&,
-    const int present, const int, const int, const int )
+void KTTSD::notificationSignal( const QString& event, const QString& fromApp,
+    const QString &text, const QString& sound, const QString& /*file*/,
+    const int present, const int /*level*/, const int /*windId*/, const int /*eventId*/)
 {
     if (!m_speaker) return;
-    if (!text.isNull())
-        if ( m_speechData->notify )
-            if (!m_speechData->notifyPopupsOnly ||
-                (present & (KNotifyClient::Messagebox | KNotifyClient::PassivePopup)))
-                if (!m_speechData->notifyPassivePopupsOnly ||
-                    ( present & KNotifyClient::PassivePopup ))
+    // kdDebug() << "KTTSD:notificationSignal: event: " << event << " fromApp: " << fromApp << 
+    //     " text: " << text << " sound: " << sound << " file: " << file << " present: " << present <<
+    //    " level: " << level << " windId: " << windId << " eventId: " << eventId << endl;
+    if ( m_speechData->notify )
+        if ( !m_speechData->notifyExcludeEventsWithSound || sound.isEmpty() )
+        {
+            bool found = false;
+            NotifyOptions notifyOptions;
+            QString msg;
+            QString talker;
+            // Check for app-specific action.
+            if ( m_speechData->notifyAppMap.contains( fromApp ) )
+            {
+                NotifyEventMap notifyEventMap = m_speechData->notifyAppMap[ fromApp ];
+                if ( notifyEventMap.contains( event ) )
+                {
+                    found = true;
+                    notifyOptions = notifyEventMap[ event ];
+                } else {
+                    // Check for app-specific default.
+                    if ( notifyEventMap.contains( "default" ) )
                     {
-                        m_speechData->enqueueMessage(text, NULL, getAppId());
-                        m_speaker->doUtterances();
+                        found = true;
+                        notifyOptions = notifyEventMap[ "default" ];
+                        notifyOptions.eventName = QString::null;
                     }
+                }
+            }
+            // If no app-specific action, try default.
+            if ( !found )
+            {
+                switch ( m_speechData->notifyDefaultPresent )
+                {
+                    case NotifyPresent::None:
+                        found = false;
+                        break;
+                    case NotifyPresent::Dialog:
+                        found = (
+                            (present & KNotifyClient::Messagebox)
+                            &&
+                            !(present & KNotifyClient::PassivePopup)
+                            );
+                        break;
+                    case NotifyPresent::Passive:
+                        found = (
+                            !(present & KNotifyClient::Messagebox)
+                            &&
+                            (present & KNotifyClient::PassivePopup)
+                            );
+                        break;
+                    case NotifyPresent::DialogAndPassive:
+                        found = (
+                            (present & KNotifyClient::Messagebox)
+                            &&
+                            (present & KNotifyClient::PassivePopup)
+                            );
+                        break;
+                    case NotifyPresent::All:
+                        found = true;
+                        break;
+                }
+                if ( found )
+                    notifyOptions = m_speechData->notifyDefaultOptions;
+            }
+            if ( found )
+            {
+                int action = notifyOptions.action;
+                talker = notifyOptions.talker;
+                switch ( action )
+                {
+                    case NotifyAction::DoNotSpeak:
+                        break;
+                    case NotifyAction::SpeakEventName:
+                        if (notifyOptions.eventName.isEmpty())
+                            msg = NotifyEvent::getEventName( fromApp, event );
+                        else
+                            msg = notifyOptions.eventName;
+                        break;
+                    case NotifyAction::SpeakMsg:
+                        msg = text;
+                        break;
+                    case NotifyAction::SpeakCustom:
+                        msg = notifyOptions.customMsg;
+                        msg.replace( "%a", fromApp );
+                        msg.replace( "%m", text );
+                        if ( msg.contains( "%e" ) )
+                        {
+                            if ( notifyOptions.eventName.isEmpty() )
+                                msg.replace( "%e", NotifyEvent::getEventName( fromApp, event ) );
+                            else
+                                msg.replace( "%e", notifyOptions.eventName );
+                        }
+                        break;
+                }
+            }
+            // Queue msg if we should speak something.
+            if ( !msg.isEmpty() )
+            {
+                QString fromApps = fromApp + ",knotify";
+                m_speechData->enqueueMessage( msg, talker, fromApps.utf8() );
+                m_speaker->doUtterances();
+            }
+        }
 }
 
 // Slots for the speaker object
@@ -926,7 +1104,7 @@ kspeech::kspeech(const QCString& objId, QObject *parent, const char *name) :
 }
 
 // Destructor.
-kspeech::~kspeech() { };
+kspeech::~kspeech() { }
 
 // Delegate all DCOP methods to KTTSD object.
 /*virtual*/ bool kspeech::supportsMarkup(const QString &talker, uint markupType) const
@@ -943,6 +1121,8 @@ kspeech::~kspeech() { };
             { m_kttsd.setSentenceDelimiter(delimiter); }
 /*virtual*/ uint kspeech::setText(const QString &text, const QString &talker)
             { return m_kttsd.setText(text, talker); }
+/*virtual*/ uint kspeech::sayText(const QString &text, const QString &talker)
+            { return m_kttsd.sayText(text, talker); }
 /*virtual*/ int kspeech::appendText(const QString &text, uint jobNum)
             { return m_kttsd.appendText(text, jobNum); }
 /*virtual*/ uint kspeech::setFile(const QString &filename, const QString &talker,
@@ -996,6 +1176,8 @@ kspeech::~kspeech() { };
             { m_kttsd.kttsdExit(); }
 /*virtual*/ void kspeech::reinit()
             { m_kttsd.reinit(); }
+/*virtual*/ QString kspeech::version()
+            { return m_kttsd.version(); }
 
 #include "kttsd.moc"
 
