@@ -1,20 +1,26 @@
 /***************************************************** vim:set ts=4 sw=4 sts=4:
-  KTTSD main class
-  -------------------
+  KTTS Manager Program
+  --------------------
   Copyright:
   (C) 2004 by Gary Cramblitt <garycramblitt@comcast.net>
   -------------------
   Original author: Gary Cramblitt <garycramblitt@comcast.net>
   Current Maintainer: Gary Cramblitt <garycramblitt@comcast.net>
- ******************************************************************************/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; version 2 of the License or later.      *
- *                                                                         *
- ***************************************************************************/
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ ******************************************************************************/
 
 // Qt includes.
 #include <qimage.h>
@@ -51,7 +57,7 @@ int main (int argc, char *argv[])
     KGlobal::locale()->setMainCatalogue("kttsd");
 
     KAboutData aboutdata("kttsmgr", I18N_NOOP("KTTSMgr"),
-        "0.3.5.1", I18N_NOOP("Text-to-Speech Manager"),
+        "0.3.5.2", I18N_NOOP("Text-to-Speech Manager"),
         KAboutData::License_GPL, "(C) 2002, José Pablo Ezequiel Fernández");
     aboutdata.addAuthor("José Pablo Ezequiel Fernández",I18N_NOOP("Original Author"),"pupeno@pupeno.com");
     aboutdata.addAuthor("Gary Cramblitt", I18N_NOOP("Maintainer"),"garycramblitt@comcast.net");
